# Test File

```cpp
#include <librapid>

int main() {
	fmt::print("Hello, World\n");
	return 0;
}
```

<div align="center">
  <a href="https://star-history.com/#Librapid/librapid/#date">
    <img src="https://api.star-history.com/svg?repos=LibRapid/librapid&type=Date" alt="Star History" width="700">
  </a>
</div>

::::{important}
:::{note}
This text is **standard** _Markdown_
:::
::::

```{math}
   \begin{equation}
        \sum_{x=1}^{\infty} \frac{1}{x^2} = \frac{\pi ^2}{6} 
   \end{equation}
```

<div class="admonition">
<p>Some **content**</p>
  <div class="admonition tip">
  <div class="title">A *title*</div>
  <p>Paragraph 1</p>
  <p>Paragraph 2</p>
  </div>
</div>
